Learn R Programming

betaselectr (version 0.1.3)

getCall.lm_betaselect: Call in an 'lm_betaselect' or 'glm_betaselect' Object

Description

The getCall-method for an lm_betaselect-class or glm_betaselectd-class objects.

Usage

# S3 method for lm_betaselect
getCall(
  x,
  what = c("lm_betaselect", "beta", "standardized", "raw", "unstandardized"),
  ...
)

# S3 method for glm_betaselect getCall( x, what = c("glm_betaselect", "beta", "standardized", "raw", "unstandardized"), ... )

Value

It returns the call requested.

Arguments

x

An lm_betaselect-class or glm_betaselect-class object from which the call is to be extracted.

what

Which call to extract. For "lm_betaselect" or "glm_betaselect" the call to lm_betaselect() or glm_betaselect() is extracted. For "beta" or "standardized", the call used to fit the model after selected variables standardized is extracted. For "raw" or "unstandardized", the call used to fit hte model before standardization is extracted.

...

Additional arguments. Ignored.

Details

This works in the same way the default getCall-method does for the outputs of stats::lm() and stats::glm().

See Also

lm_betaselect(), glm_betaselect(), and stats::getCall()

Examples

Run this code

data(data_test_mod_cat)

lm_beta_x <- lm_betaselect(dv ~ iv*mod + cov1,
                           data = data_test_mod_cat,
                           to_standardize = "iv")
getCall(lm_beta_x)
getCall(lm_beta_x, what = "beta")
getCall(lm_beta_x, what = "raw")

Run the code above in your browser using DataLab