Learn R Programming

betaselectr (version 0.1.3)

confint.lav_betaselect: Confidence Intervals for a 'lav_betaselect'-Class Object

Description

Return the confidence intervals of betas-select in the output of lav_betaselect().

Usage

# S3 method for lav_betaselect
confint(object, parm, level = 0.95, ...)

Value

A two-column matrix of the confidence intervals.

Arguments

object

The output of lav_betaselect().

parm

Ignored due to the complexity in the naming. The confidence intervals of all parameters are always returned.

level

The level of confidence. Ignored because the intervals should be formed when calling lav_betaselect().

...

Optional arguments. Ignored.

Details

The type of confidence intervals depends on the call to lav_betaselect(). This function does not recompute the confidence interval.

See Also

lav_betaselect()

Examples

Run this code

library(lavaan)
# Need to mean-center iv and mod
data_test_medmod$iv <- data_test_medmod$iv - mean(data_test_medmod$iv)
data_test_medmod$mod <- data_test_medmod$mod - mean(data_test_medmod$mod)
mod <-
"
med ~ iv + mod + iv:mod
dv ~ med + iv
"
fit <- sem(mod,
           data_test_medmod,
           fixed.x = TRUE)
summary(fit)
fit_beta <- lav_betaselect(fit,
                           to_standardize = c("iv", "dv"))
confint(fit_beta)

Run the code above in your browser using DataLab